@@ -195,7 +195,7 @@ def upsert(
         with open(file, 'r') as file:
             simple_metric_conf = json.loads(file.read())
 
-        simple_request = SimpleUpsertMetricRequest.from_dict(simple_metric_conf)
+        simple_request = SimpleUpsertMetricRequest(**simple_metric_conf)
 
         client.upsert_metric_from_simple_template(sumr=simple_request,
                                                   existing_metric_id=existing_metric_id)
